@@ -154,7 +154,7 @@ def _reload(config_dir: Path, device: str):
     client = OpenHaspClient()
 
     for device in devices:
-        client.command(device, "run", "clearpage all")
+        client.command(device, "clearpage", "all")
         client.command(device, "run", "L:/boot.cmd")
 
 
@@ -199,10 +199,7 @@ def _cmd(config_dir: Path, device: str, command: str, payload: str):
     from openhasp_config_manager.openhasp import OpenHaspClient
     client = OpenHaspClient()
 
-    import json
     for device in devices:
-        if len(payload) > 0:
-            payload = json.loads(payload)
         client.command(device, command, payload)
 
 
